@@ -8,7 +8,7 @@ NULL
 #' both lines and points stay connected, and b) provides a visual effect
 #' by adding a small gap between the point and the end of line.
 #' \code{geom_pointline} combines \code{\link[ggplot2]{geom_point}} and
-#' \code{\link[ggplot2]{geom_line}}.
+#' \code{\link[ggplot2]{geom_path}}.
 #' 
 #' \code{geom_pointpath} connects the observations in the same order in which
 #' they appear in the data.
@@ -18,9 +18,10 @@ NULL
 #' connect observations within the same group! However,
 #' if \code{linecolour} is \emph{not} \code{waiver()}, connections
 #' will be made between groups, but possible in an incorrect order.
-#' \strong{Note!} If the x-variable is a factor, the `group' aesthetic will
-#' \emph{also} use this, thus lines between x-values are not grouped.
-#' Use \code{aes(group=...)} to enforce a group across x-values.
+#' 
+#' 
+#' 
+#' 
 #' 
 #' @section Aesthetics:
 #' \code{geom_pointline} and \code{geom_pointpath} understands the following 
@@ -61,14 +62,15 @@ NULL
 #' @param inherit.aes If \code{FALSE}, overrides the default aesthetic, rather
 #'   than combining with them. This is most useful for helper functions that
 #'   define both data and aesthetics and shouldn't inherit behaviour from the 
-#'   default plot specification, e.g. \code{\link[ggplot2]{borders}}.
+#'   default plot specification.
 #' @param linesize Width of of line.
-#' @param distance Gap size between point and end of lines when the distance
-#'   between points exceeds \code{threshold};
+#' @param distance Gap size between point and end of lines;
 #'   use \code{\link[grid]{unit}}. Is converted to 'pt' if given as simple numeric.
-#' @param threshold,shorten Use \code{threshold} to adjust when the line between
-#'   two points should be drawn with a gap (per argument above) or shortened by
-#'   the proportion given by \code{shorten}.  
+#'   When \code{NULL} or \code{NA}, gapping and \code{shorten}/\code{treshold}
+#'   is disabled. To keep the latter, set to 0.
+#' @param shorten,threshold When points are closer than \code{threshold},
+#'   shorten the line by the proportion in \code{shorten} instead of adding
+#'   a gap by \code{distance}.
 #' @param linecolour,linecolor When not \code{waiver()}, the line is drawn with 
 #'   this colour instead of that set by aesthetic \code{colour}.
 #' 
@@ -141,15 +143,18 @@ GeomPointPath <- ggplot2::ggproto('GeomPointPath',
                         arrow = NULL,
                         lineend = "butt", linejoin = "round", linemitre = 1
                         ) {
-    # Test input parameters
-    if (is.null(distance) || is.na(distance)) 
-      distance <- grid::unit(0, 'pt')
 
+    # Test input parameters
+    if (is.null(distance) || is.na(distance)) {
+      distance=grid::unit(0, 'pt')
+      threshold = 0
+    }
     if (!grid::is.unit(distance) && is.numeric(distance)) 
       distance <- grid::unit(distance, 'pt')
     
     # Contents of GeomPoint$draw_panel in geom-point.r
     coords <- coord$transform(data, panel_params)
+    coords_p <- coords
     gr_points <- ggplot2:::ggname("geom_point",
            grid::pointsGrob(
              coords$x, coords$y,
@@ -163,6 +168,7 @@ GeomPointPath <- ggplot2::ggproto('GeomPointPath',
              )
            )
     )
+    # gr_points <- GeomPoint$draw_panel(data, panel_params, coord, na.rm)
     
     # Contents of GeomPath$draw_panel in geom-path
     if (!anyDuplicated(data$group)) {
@@ -208,17 +214,26 @@ GeomPointPath <- ggplot2::ggproto('GeomPointPath',
       length <- sqrt(deltax**2 + deltay**2);
     })
     
-    if (any(munched$length > threshold, na.rm=TRUE) &
-        as.numeric(distance) != 0) {
+    if (any(munched$length > threshold, na.rm=TRUE)) {
       # Calculate angle between each pair of points and move endpoints:
-      df <- within(munched[munched$length > threshold,], {
-        theta = atan2(deltay, deltax);
-        size = grid::unit(size, 'pt');
-        x = grid::unit(x, 'native') + size*cos(theta) + distance*cos(theta);
-        x1 = grid::unit(x1, 'native') - size*cos(theta) - distance*cos(theta);
-        y = grid::unit(y, 'native') + size*sin(theta) + distance*sin(theta);
-        y1 = grid::unit(y1, 'native') - size*sin(theta) - distance*sin(theta);
-      })      
+      if (as.numeric(distance) != 0) {
+        df <- within(munched[munched$length > threshold,], {
+          theta = atan2(deltay, deltax);
+          size = grid::unit(size, 'pt');
+          x = grid::unit(x, 'native') + size*cos(theta) + distance*cos(theta);
+          x1 = grid::unit(x1, 'native') - size*cos(theta) - distance*cos(theta);
+          y = grid::unit(y, 'native') + size*sin(theta) + distance*sin(theta);
+          y1 = grid::unit(y1, 'native') - size*sin(theta) - distance*sin(theta);
+        })
+      } else {
+        df <- within(munched[munched$length > threshold,], {
+          x = grid::unit(x, 'native');
+          x1 = grid::unit(x1, 'native');
+          y = grid::unit(y, 'native');
+          y1 = grid::unit(y1, 'native');
+        })
+      }
+      
       gr_distant <- with(df, grid::segmentsGrob(
         x0=x[!end], y0=y[!end], x1=x1[!end], y1=y1[!end],
         arrow = arrow,
@@ -235,10 +250,10 @@ GeomPointPath <- ggplot2::ggproto('GeomPointPath',
       if (!is.waive(linecolour)) 
         gr_distant$gp$col <- linecolour
     } else {
-      gr_distant <- ggplot2::zeroGrob()
+      gr_distant <- zeroGrob()
     }
-    
-    if (any(munched$length <= threshold, na.rm=TRUE)) {
+
+    if (threshold > 0 && any(munched$length <= threshold, na.rm=TRUE)) {
       df <- within(munched[munched$length <= threshold,], {
         x  = x + shorten/2 * deltax; x = grid::unit(x, 'native');
         y  = y + shorten/2 * deltay; y = grid::unit(y, 'native');
@@ -262,8 +277,14 @@ GeomPointPath <- ggplot2::ggproto('GeomPointPath',
       if (!is.waive(linecolour)) 
         gr_short$gp$col <- linecolour
     } else {
-      gr_short <- ggplot2::zeroGrob()
+      gr_short <- zeroGrob()
     }
+
+    
+    
+    #saveRDS(munched, 'munced.rds')
+    
+    
     
     grid::gList(gr_points, gr_distant, gr_short)
   },
@@ -280,7 +301,7 @@ geom_pointline <- function(mapping = NULL, data = NULL, stat = "identity",
                            show.legend = NA, inherit.aes = TRUE, 
                            distance = unit(3, 'pt'), 
                            shorten = 0.5,
-                           threshold = 0.1,
+                           threshold = 0.1,                           
                            lineend = "butt",
                            linejoin = "round",
                            linemitre = 1,
@@ -304,11 +325,11 @@ geom_pointline <- function(mapping = NULL, data = NULL, stat = "identity",
       na.rm = na.rm,
       distance = distance,
       shorten = shorten,
-      threshold = threshold,
+      threshold = threshold,      
       lineend = lineend,
       linejoin = linejoin,
       linemitre = linemitre,
-      linesize = linesize,
+      linesize = 0.5,
       linecolour = linecolour,
       arrow = arrow,    
       ...
@@ -329,3 +350,75 @@ GeomPointLine <- ggproto("GeomPointLine", GeomPointPath,
     }
 )
 
+
+
+
+#' @inheritParams geom_pointpath
+#' @rdname geom_pointpath
+geom_pointrangeline <- function(mapping = NULL, data = NULL, stat = "identity",
+                                position = "identity", na.rm = FALSE,
+                                show.legend = NA, inherit.aes = TRUE, 
+                                distance = unit(3, 'pt'), 
+                                lineend = "butt",
+                                linejoin = "round",
+                                linemitre = 1,
+                                linesize = 0.5,
+                                linecolour = waiver(),
+                                linecolor = waiver(),
+                                arrow = NULL,
+                                ...) {
+  stop('geom_pointrangeline has not been implemented. Sorry')
+  if (is.waive(linecolour) && !is.waive(linecolor)) linecolour <- linecolor
+  
+  layer(
+    data = data,
+    mapping = mapping,
+    stat = stat,
+    geom = GeomPointRangeLine,
+    position = position,
+    show.legend = show.legend,
+    inherit.aes = inherit.aes,
+    params = list(
+      na.rm = na.rm,
+      distance = distance,
+      lineend = lineend,
+      linejoin = linejoin,
+      linemitre = linemitre,
+      linesize = 0.5,
+      linecolour = linecolour,
+      arrow = arrow,      
+      ...
+    )
+  )
+}
+
+#' @rdname lemon-ggproto
+#' @keywords internal
+#' @format NULL
+#' @usage NULL
+#  @export
+#' @import ggplot2
+#' @import gtable
+GeomPointRangeLine <- ggproto("GeomPointRangeLine", GeomPointLine,
+  required_aes = c("x", "y", "ymin", "ymax"),
+  
+  setup_data = function(data, params) {
+    data[order(data$PANEL, data$group, data$x), ]
+  },
+  draw_panel = function(data, panel_params, coord, na.rm = FALSE,
+                        distance = grid::unit(3, 'pt'), linesize = 0.5,
+                        linecolour = waiver(),
+                        arrow = NULL,
+                        lineend = "butt", linejoin = "round", linemitre = 1
+  ) {
+    data <- transform(data, xend = x, y = ymin, yend = ymax)
+    grid::gList(ggname("geom_linerange", GeomSegment$draw_panel(data, panel_params, coord)),
+                GeomPointLine$draw_panel(data, panel_params, coord,
+                                         na.rm=na.rm, distance=distance,
+                                         linesize=linesize, linecolour=linecolour,
+                                         arrow=arrow, lineend=lineend,
+                                         linejoin=linejoin, linemitre=linemitre)
+    )
+  }
+)
+
